#!/usr/bin/env python
#   This file is part of nexdatas - Tango Server for NeXus data writer
#
#    Copyright (C) 2012-2017 DESY, Jan Kotanski <jkotan@mail.desy.de>
#
#    nexdatas is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    nexdatas is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with nexdatas.  If not, see <http://www.gnu.org/licenses/>.
#

""" setup.py for nexus template components for P10 """

import os
from distutils.core import setup


def read(fname):
    """reading a file

    :param fname: file name
    :type fname: :obj:`str`
    """
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

PKG = "nxsextrasp10"
IPKG = __import__(PKG)

# from sphinx.setup_command import BuildDoc


release = IPKG.__version__
version = ".".join(release.split(".")[:2])
name = "NXSExtrasP10"
author = "Jan Kotanski",
glicense = "GNU GENERAL PUBLIC LICENSE, version 3",

#: metadata for distutils
SETUPDATA = dict(
    name="nexdatas.extrasp10",
    version=IPKG.__version__,
    author=author,
    author_email="jankotan@gmail.com",
    maintainer="Jan Kotanski",
    maintainer_email="jankotan@gmail.com",
    license=glicense,
    description=("nexus template components for P10"),
    keywords="configuration writer Tango component nexus data tools",
    url="http://github.com/nexdatas/",
    platforms=("Linux"),
    packages=["nxsextrasp10"],
    package_data={'nxsextrasp10': ['*.xml']},
    #    cmdclass={'build_sphinx': BuildDoc},
    data_files=[('share/nxstools',
                 [
                     'scripts/nxsconf_haspp10e1.sh',
                     'scripts/nxsconf_haspp10e2.sh',
                     'scripts/nxsconf_haspp10lab.sh',
                 ]),
                ('share/nxstools',
                 [
                     'xml/online_haspp10e1.xml',
                     'xml/online_haspp10e2.xml',
                     'xml/online_haspp10lab.xml',
                 ])
                ],
    command_options={
        'build_sphinx': {
            'project': ('setup.py', name),
            'version': ('setup.py', version),
            'release': ('setup.py', release)}},
    long_description=read('README.rst')
)


def main():
    """ the main function
    """
    setup(**SETUPDATA)


if __name__ == '__main__':
    main()
